@@ -18,6 +18,7 @@ REGIONS = {
     "N439K": "NC_045512:22877-22879",
     "N440K": "NC_045512:22880-22882",
     "G446S": "NC_045512:22898-22900",
+    "L452M": "NC_045512:22916-22918",
     "L452R": "NC_045512:22916-22918",
     "Y449H": "NC_045512:22907-22909",
     "Y449N": "NC_045512:22907-22909",
@@ -28,6 +29,7 @@ REGIONS = {
     "E484A": "NC_045512:23012-23014",
     "E484K": "NC_045512:23012-23014",
     "E484Q": "NC_045512:23012-23014",
+    "F486V": "NC_045512:23018-23020",
     "F490R": "NC_045512:23030-23032",
     "Q493K": "NC_045512:23039-23041",
     "Q493R": "NC_045512:23039-23041",
@@ -41,12 +43,14 @@ REGIONS = {
     "D614G": "NC_045512:23402-23404",
     "A626S": "NC_045512:23438-23441",
     "H655Y": "NC_045512:23525-23527",
+    "Q677E": "NC_045512:23591-23593",
     "Q677H": "NC_045512:23591-23593",
     "N679K": "NC_045512:23597-23599",
     "P681H": "NC_045512:23603-23605",
     "P681R": "NC_045512:23603-23605",
     "I692V": "NC_045512:23636-23638",
     "A701V": "NC_045512:23663-23665",
+    "S704L": "NC_045512:23672-23674",
     "T716I": "NC_045512:23708-23710",
     "T732A": "NC_045512:23756-23758",
 }
